Module core

Module core 

Utility methods to interact with the GitHub actions ecosystem

You can obtain injected inputs or produce an output for another step

Functions

get_input
Obtain an input from a variable
set_output
Produces an output that can be used in another step