Module actions_github::core
source · Expand description
Utility methods to interact with the GitHub actions ecosystem
You can obtain injected inputs or produce an output for another step
Functions
- Obtain an input from a variable
- Produces an output that can be used in another step