Module actions_github::logger
source · Expand description
Logging methods for the output
Functions
- Prints a debug message to the log.
- Creates an error message and prints the message to the log.
- Logs regular information message
- Returns if it’s running on a debug runner.
- Creates a notice message and prints the message to the log.
- Creates a warning message and prints the message to the log.